#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .list import list as list_cls
from .list_properties import list_properties as list_properties_cls
from .duplicate import duplicate as duplicate_cls
from .display_2 import display as display_cls
from .copy_4 import copy as copy_cls
from .add_to_graphics import add_to_graphics as add_to_graphics_cls
from .clear_history import clear_history as clear_history_cls
from .xy_plot_child import xy_plot_child


class xy_plot(NamedObject[xy_plot_child], CreatableNamedObjectMixin[xy_plot_child]):
    """
    'xy_plot' child.
    """

    fluent_name = "xy-plot"

    command_names = \
        ['list', 'list_properties', 'duplicate', 'display', 'copy',
         'add_to_graphics', 'clear_history']

    _child_classes = dict(
        list=list_cls,
        list_properties=list_properties_cls,
        duplicate=duplicate_cls,
        display=display_cls,
        copy=copy_cls,
        add_to_graphics=add_to_graphics_cls,
        clear_history=clear_history_cls,
    )

    child_object_type: xy_plot_child = xy_plot_child
    """
    child_object_type of xy_plot.
    """
    return_type = "<object object at 0x7f7d0bd70680>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_10 import option as option_cls
from .cross_section_multicomponent import cross_section_multicomponent as cross_section_multicomponent_cls

class collision_cross_section(Group):
    """
    'collision_cross_section' child.
    """

    fluent_name = "collision-cross-section"

    child_names = \
        ['option', 'cross_section_multicomponent']

    _child_classes = dict(
        option=option_cls,
        cross_section_multicomponent=cross_section_multicomponent_cls,
    )

    return_type = "<object object at 0x7f7d7fa64e00>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .print_histogram import print_histogram as print_histogram_cls
from .write_histogram import write_histogram as write_histogram_cls

class print_write_histogram(Group):
    fluent_name = ...
    command_names = ...

    def print_histogram(self, domain: str, cell_function: str, min_val: Union[float, str], max_val: Union[float, str], num_division: int, set_all_zones: bool, threads_list: List[str], file_name: str, overwrite: bool):
        """
        Print a histogram of a scalar quantity.
        
        Parameters
        ----------
            domain : str
                'domain' child.
            cell_function : str
                'cell_function' child.
            min_val : real
                'min_val' child.
            max_val : real
                'max_val' child.
            num_division : int
                'num_division' child.
            set_all_zones : bool
                'set_all_zones' child.
            threads_list : typing.List[str]
                'threads_list' child.
            file_name : str
                'file_name' child.
            overwrite : bool
                'overwrite' child.
        
        """

    def write_histogram(self, domain: str, cell_function: str, min_val: Union[float, str], max_val: Union[float, str], num_division: int, set_all_zones: bool, threads_list: List[str], file_name: str, overwrite: bool):
        """
        Write a histogram of a scalar quantity to a file.
        
        Parameters
        ----------
            domain : str
                'domain' child.
            cell_function : str
                'cell_function' child.
            min_val : real
                'min_val' child.
            max_val : real
                'max_val' child.
            num_division : int
                'num_division' child.
            set_all_zones : bool
                'set_all_zones' child.
            threads_list : typing.List[str]
                'threads_list' child.
            file_name : str
                'file_name' child.
            overwrite : bool
                'overwrite' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .enable_instability_detector import enable_instability_detector as enable_instability_detector_cls
from .set_cfl_limit import set_cfl_limit as set_cfl_limit_cls
from .set_cfl_type import set_cfl_type as set_cfl_type_cls
from .set_velocity_limit import set_velocity_limit as set_velocity_limit_cls
from .unstable_event_outer_iterations import unstable_event_outer_iterations as unstable_event_outer_iterations_cls

class instability_detector(Group):
    """
    'instability_detector' child.
    """

    fluent_name = "instability-detector"

    child_names = \
        ['enable_instability_detector', 'set_cfl_limit', 'set_cfl_type',
         'set_velocity_limit', 'unstable_event_outer_iterations']

    _child_classes = dict(
        enable_instability_detector=enable_instability_detector_cls,
        set_cfl_limit=set_cfl_limit_cls,
        set_cfl_type=set_cfl_type_cls,
        set_velocity_limit=set_velocity_limit_cls,
        unstable_event_outer_iterations=unstable_event_outer_iterations_cls,
    )

    return_type = "<object object at 0x7fd5ebcfc470>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .from_zone_type import from_zone_type as from_zone_type_cls
from .from_zone_name import from_zone_name as from_zone_name_cls
from .phase_25 import phase as phase_cls

class compute_defaults(Command):
    """
    'compute_defaults' command.
    
    Parameters
    ----------
        from_zone_type : str
            'from_zone_type' child.
        from_zone_name : str
            'from_zone_name' child.
        phase : str
            'phase' child.
    
    """

    fluent_name = "compute-defaults"

    argument_names = \
        ['from_zone_type', 'from_zone_name', 'phase']

    _child_classes = dict(
        from_zone_type=from_zone_type_cls,
        from_zone_name=from_zone_name_cls,
        phase=phase_cls,
    )

    return_type = "<object object at 0x7f7d0be8cbc0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .bodies import bodies as bodies_cls
from .groups import groups as groups_cls

class parts_child(Group):
    """
    'child_object_type' of parts.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['bodies', 'groups']

    _child_classes = dict(
        bodies=bodies_cls,
        groups=groups_cls,
    )

    return_type = "<object object at 0x7f7d0bfd4640>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_10 import option as option_cls
from .value import value as value_cls
from .single_rate import single_rate as single_rate_cls
from .two_competing_rates import two_competing_rates as two_competing_rates_cls
from .cpd_model import cpd_model as cpd_model_cls

class devolatilization_model(Group):
    """
    'devolatilization_model' child.
    """

    fluent_name = "devolatilization-model"

    child_names = \
        ['option', 'value', 'single_rate', 'two_competing_rates', 'cpd_model']

    _child_classes = dict(
        option=option_cls,
        value=value_cls,
        single_rate=single_rate_cls,
        two_competing_rates=two_competing_rates_cls,
        cpd_model=cpd_model_cls,
    )

    return_type = "<object object at 0x7f79c84ae1b0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .fluid import fluid as fluid_cls
from .solid import solid as solid_cls
from .mixture import mixture as mixture_cls
from .inert_particle import inert_particle as inert_particle_cls
from .droplet_particle import droplet_particle as droplet_particle_cls
from .combusting_particle import combusting_particle as combusting_particle_cls
from .particle_mixture import particle_mixture as particle_mixture_cls
from .list_materials import list_materials as list_materials_cls
from .copy_database_material_by_name import copy_database_material_by_name as copy_database_material_by_name_cls
from .copy_database_material_by_formula import copy_database_material_by_formula as copy_database_material_by_formula_cls

class materials(Group):
    fluent_name = ...
    child_names = ...
    fluid: fluid_cls = ...
    solid: solid_cls = ...
    mixture: mixture_cls = ...
    inert_particle: inert_particle_cls = ...
    droplet_particle: droplet_particle_cls = ...
    combusting_particle: combusting_particle_cls = ...
    particle_mixture: particle_mixture_cls = ...
    command_names = ...

    def list_materials(self, ):
        """
        'list_materials' command.
        """

    def copy_database_material_by_name(self, type: str, name: str):
        """
        'copy_database_material_by_name' command.
        
        Parameters
        ----------
            type : str
                'type' child.
            name : str
                'name' child.
        
        """

    def copy_database_material_by_formula(self, type: str, formula: str):
        """
        'copy_database_material_by_formula' command.
        
        Parameters
        ----------
            type : str
                'type' child.
            formula : str
                'formula' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .feature_angle import feature_angle as feature_angle_cls

class feature(Group):
    """
    'feature' child.
    """

    fluent_name = "feature"

    child_names = \
        ['feature_angle']

    _child_classes = dict(
        feature_angle=feature_angle_cls,
    )

    return_type = "<object object at 0x7fd5ebc0a050>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .compute import compute as compute_cls

class compute(Group):
    """
    'compute' child.
    """

    fluent_name = "compute"

    child_names = \
        ['compute']

    _child_classes = dict(
        compute=compute_cls,
    )

    return_type = "<object object at 0x7fd5ebd340f0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .only_list_case_boundaries import only_list_case_boundaries as only_list_case_boundaries_cls
from .use_inherent_material_color import use_inherent_material_color as use_inherent_material_color_cls
from .type_name import type_name as type_name_cls
from .reset_2 import reset as reset_cls

class by_type(Group):
    """
    'by_type' child.
    """

    fluent_name = "by-type"

    child_names = \
        ['only_list_case_boundaries', 'use_inherent_material_color',
         'type_name']

    command_names = \
        ['reset']

    _child_classes = dict(
        only_list_case_boundaries=only_list_case_boundaries_cls,
        use_inherent_material_color=use_inherent_material_color_cls,
        type_name=type_name_cls,
        reset=reset_cls,
    )

    return_type = "<object object at 0x7fab935710f0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .report_type import report_type as report_type_cls
from .thread_id_list import thread_id_list as thread_id_list_cls
from .domain import domain as domain_cls
from .cell_function_1 import cell_function as cell_function_cls
from .current_domain import current_domain as current_domain_cls
from .write_to_file import write_to_file as write_to_file_cls
from .file_name_1 import file_name as file_name_cls
from .append_data import append_data as append_data_cls
from .overwrite import overwrite as overwrite_cls

class volume_integrals(Command):
    fluent_name = ...
    argument_names = ...
    report_type: report_type_cls = ...
    thread_id_list: thread_id_list_cls = ...
    domain: domain_cls = ...
    cell_function: cell_function_cls = ...
    current_domain: current_domain_cls = ...
    write_to_file: write_to_file_cls = ...
    file_name: file_name_cls = ...
    append_data: append_data_cls = ...
    overwrite: overwrite_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .enhanced_numerics import enhanced_numerics as enhanced_numerics_cls
from .alternate_bc_formulation import alternate_bc_formulation as alternate_bc_formulation_cls
from .analytical_thermodynamic_derivatives import analytical_thermodynamic_derivatives as analytical_thermodynamic_derivatives_cls

class compressible_flow(Group):
    """
    Multiphase compressible numerics options menu.
    """

    fluent_name = "compressible-flow"

    child_names = \
        ['enhanced_numerics', 'alternate_bc_formulation',
         'analytical_thermodynamic_derivatives']

    _child_classes = dict(
        enhanced_numerics=enhanced_numerics_cls,
        alternate_bc_formulation=alternate_bc_formulation_cls,
        analytical_thermodynamic_derivatives=analytical_thermodynamic_derivatives_cls,
    )

    return_type = "<object object at 0x7f79a6990720>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .computed_heat_rejection import computed_heat_rejection as computed_heat_rejection_cls
from .inlet_temperature import inlet_temperature as inlet_temperature_cls
from .outlet_temperature import outlet_temperature as outlet_temperature_cls
from .mass_flow_rate_1 import mass_flow_rate as mass_flow_rate_cls
from .specific_heat_5 import specific_heat as specific_heat_cls

class heat_exchange(Group):
    """
    'heat_exchange' child.
    """

    fluent_name = "heat-exchange"

    command_names = \
        ['computed_heat_rejection', 'inlet_temperature', 'outlet_temperature',
         'mass_flow_rate', 'specific_heat']

    _child_classes = dict(
        computed_heat_rejection=computed_heat_rejection_cls,
        inlet_temperature=inlet_temperature_cls,
        outlet_temperature=outlet_temperature_cls,
        mass_flow_rate=mass_flow_rate_cls,
        specific_heat=specific_heat_cls,
    )

    return_type = "<object object at 0x7f7d0bcf63b0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .contact_face import contact_face as contact_face_cls
from .resistance_value import resistance_value as resistance_value_cls

class add_contact_resistance(Command):
    """
    'add_contact_resistance' command.
    
    Parameters
    ----------
        contact_face : str
            Set contact face.
        resistance_value : real
            Set resistance value.
    
    """

    fluent_name = "add-contact-resistance"

    argument_names = \
        ['contact_face', 'resistance_value']

    _child_classes = dict(
        contact_face=contact_face_cls,
        resistance_value=resistance_value_cls,
    )

    return_type = "<object object at 0x7fabc468a550>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .first_to_second_order_blending_dbns import first_to_second_order_blending_dbns as first_to_second_order_blending_dbns_cls

class numerics_dbns(Group):
    """
    'numerics_dbns' child.
    """

    fluent_name = "numerics-dbns"

    child_names = \
        ['first_to_second_order_blending_dbns']

    _child_classes = dict(
        first_to_second_order_blending_dbns=first_to_second_order_blending_dbns_cls,
    )

    return_type = "<object object at 0x7fd5ebd34e70>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .convergence_acceleration_type import convergence_acceleration_type as convergence_acceleration_type_cls
from .casm_cutoff_multiplier import casm_cutoff_multiplier as casm_cutoff_multiplier_cls

class convergence_acceleration_for_stretched_meshes(Group):
    """
    Enable convergence acceleration for stretched meshes to improve the convergence of the implicit pressure based solver on meshes with high cell stretching.
    """

    fluent_name = "convergence-acceleration-for-stretched-meshes"

    child_names = \
        ['convergence_acceleration_type', 'casm_cutoff_multiplier']

    _child_classes = dict(
        convergence_acceleration_type=convergence_acceleration_type_cls,
        casm_cutoff_multiplier=casm_cutoff_multiplier_cls,
    )

    return_type = "<object object at 0x7f7d0bfd4f30>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_3 import option as option_cls
from .all import all as all_cls
from .feature import feature as feature_cls
from .outline import outline as outline_cls

class edge_type(Group):
    """
    'edge_type' child.
    """

    fluent_name = "edge-type"

    child_names = \
        ['option', 'all', 'feature', 'outline']

    _child_classes = dict(
        option=option_cls,
        all=all_cls,
        feature=feature_cls,
        outline=outline_cls,
    )

    return_type = "<object object at 0x7f79a689a420>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .domain_val import domain_val as domain_val_cls

class uds_flow(Command):
    """
    'uds_flow' command.
    
    Parameters
    ----------
        domain_val : str
            'domain_val' child.
    
    """

    fluent_name = "uds-flow"

    argument_names = \
        ['domain_val']

    _child_classes = dict(
        domain_val=domain_val_cls,
    )

    return_type = "<object object at 0x7f7d0bd2fef0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enable_prod_limiter import enable_prod_limiter as enable_prod_limiter_cls
from .clip_factor import clip_factor as clip_factor_cls

class production_limiter(Group):
    fluent_name = ...
    child_names = ...
    enable_prod_limiter: enable_prod_limiter_cls = ...
    clip_factor: clip_factor_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .convergence_reports import convergence_reports as convergence_reports_cls
from .frequency_1 import frequency as frequency_cls
from .condition import condition as condition_cls
from .check_for import check_for as check_for_cls

class convergence_conditions(Group):
    fluent_name = ...
    child_names = ...
    convergence_reports: convergence_reports_cls = ...
    frequency: frequency_cls = ...
    condition: condition_cls = ...
    check_for: check_for_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .display import display as display_cls
from .mesh_child_1 import mesh_child


class mesh(NamedObject[mesh_child], CreatableNamedObjectMixin[mesh_child]):
    fluent_name = ...
    command_names = ...

    def display(self, object_name: str):
        """
        'display' command.
        
        Parameters
        ----------
            object_name : str
                'object_name' child.
        
        """

    child_object_type = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .front_faces_transparent import front_faces_transparent as front_faces_transparent_cls
from .projection_1 import projection as projection_cls
from .axes_1 import axes as axes_cls
from .ruler import ruler as ruler_cls
from .title import title as title_cls
from .boundary_marker import boundary_marker as boundary_marker_cls
from .anti_aliasing import anti_aliasing as anti_aliasing_cls
from .reflections import reflections as reflections_cls
from .static_shadows import static_shadows as static_shadows_cls
from .dynamic_shadows import dynamic_shadows as dynamic_shadows_cls
from .grid_plane import grid_plane as grid_plane_cls
from .headlights import headlights as headlights_cls
from .lighting import lighting as lighting_cls
from .view_name import view_name as view_name_cls

class display_states_child(Group):
    fluent_name = ...
    child_names = ...
    front_faces_transparent: front_faces_transparent_cls = ...
    projection: projection_cls = ...
    axes: axes_cls = ...
    ruler: ruler_cls = ...
    title: title_cls = ...
    boundary_marker: boundary_marker_cls = ...
    anti_aliasing: anti_aliasing_cls = ...
    reflections: reflections_cls = ...
    static_shadows: static_shadows_cls = ...
    dynamic_shadows: dynamic_shadows_cls = ...
    grid_plane: grid_plane_cls = ...
    headlights: headlights_cls = ...
    lighting: lighting_cls = ...
    view_name: view_name_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .name_2 import name as name_cls
from .p0 import p0 as p0_cls
from .p1 import p1 as p1_cls
from .number_of_points import number_of_points as number_of_points_cls

class rake_surface_child(Group):
    fluent_name = ...
    child_names = ...
    name: name_cls = ...
    p0: p0_cls = ...
    p1: p1_cls = ...
    number_of_points: number_of_points_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .filepath import filepath as filepath_cls

class export_design_table(Command):
    """
    Export Design Point Table.
    
    Parameters
    ----------
        filepath : str
            'filepath' child.
    
    """

    fluent_name = "export-design-table"

    argument_names = \
        ['filepath']

    _child_classes = dict(
        filepath=filepath_cls,
    )

    return_type = "<object object at 0x7f7d0bcf6a20>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .area import area as area_cls
from .depth import depth as depth_cls
from .density_6 import density as density_cls
from .enthalpy import enthalpy as enthalpy_cls
from .length import length as length_cls
from .pressure import pressure as pressure_cls
from .temperature_3 import temperature as temperature_cls
from .yplus import yplus as yplus_cls
from .velocity_2 import velocity as velocity_cls
from .viscosity_3 import viscosity as viscosity_cls
from .zone import zone as zone_cls
from .compute import compute as compute_cls
from .list_val import list_val as list_val_cls

class reference_values(Group):
    fluent_name = ...
    child_names = ...
    area: area_cls = ...
    depth: depth_cls = ...
    density: density_cls = ...
    enthalpy: enthalpy_cls = ...
    length: length_cls = ...
    pressure: pressure_cls = ...
    temperature: temperature_cls = ...
    yplus: yplus_cls = ...
    velocity: velocity_cls = ...
    viscosity: viscosity_cls = ...
    zone: zone_cls = ...
    command_names = ...

    def compute(self, from_zone_type: str, from_zone_name: str, phase: str):
        """
        'compute' command.
        
        Parameters
        ----------
            from_zone_type : str
                'from_zone_type' child.
            from_zone_name : str
                'from_zone_name' child.
            phase : str
                'phase' child.
        
        """

    def list_val(self, ):
        """
        'list_val' command.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .heat_flux_relaxation_factor import heat_flux_relaxation_factor as heat_flux_relaxation_factor_cls
from .show_expert_options import show_expert_options as show_expert_options_cls
from .two_resistance_boiling_framework import two_resistance_boiling_framework as two_resistance_boiling_framework_cls

class boiling(Group):
    fluent_name = ...
    child_names = ...
    heat_flux_relaxation_factor: heat_flux_relaxation_factor_cls = ...
    show_expert_options: show_expert_options_cls = ...
    two_resistance_boiling_framework: two_resistance_boiling_framework_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enable_instability_detector import enable_instability_detector as enable_instability_detector_cls
from .set_cfl_limit import set_cfl_limit as set_cfl_limit_cls
from .set_cfl_type import set_cfl_type as set_cfl_type_cls
from .set_velocity_limit import set_velocity_limit as set_velocity_limit_cls
from .unstable_event_outer_iterations import unstable_event_outer_iterations as unstable_event_outer_iterations_cls

class instability_detector(Group):
    fluent_name = ...
    child_names = ...
    enable_instability_detector: enable_instability_detector_cls = ...
    set_cfl_limit: set_cfl_limit_cls = ...
    set_cfl_type: set_cfl_type_cls = ...
    set_velocity_limit: set_velocity_limit_cls = ...
    unstable_event_outer_iterations: unstable_event_outer_iterations_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .verbosity_6 import verbosity as verbosity_cls
from .skewness_neighbor_coupling import skewness_neighbor_coupling as skewness_neighbor_coupling_cls
from .hybrid_nita_settings import hybrid_nita_settings as hybrid_nita_settings_cls

class nita_expert_controls(Group):
    fluent_name = ...
    child_names = ...
    verbosity: verbosity_cls = ...
    skewness_neighbor_coupling: skewness_neighbor_coupling_cls = ...
    hybrid_nita_settings: hybrid_nita_settings_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .x import x as x_cls
from .x_2 import x_2 as x_2_cls
from .y import y as y_cls
from .y_2 import y_2 as y_2_cls
from .z import z as z_cls
from .z_2 import z_2 as z_2_cls
from .magnitude import magnitude as magnitude_cls

class angular_velocity(Group):
    """
    'angular_velocity' child.
    """

    fluent_name = "angular-velocity"

    child_names = \
        ['x', 'x_2', 'y', 'y_2', 'z', 'z_2', 'magnitude']

    _child_classes = dict(
        x=x_cls,
        x_2=x_2_cls,
        y=y_cls,
        y_2=y_2_cls,
        z=z_cls,
        z_2=z_2_cls,
        magnitude=magnitude_cls,
    )

    return_type = "<object object at 0x7f7d7fc63d50>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name_2 import name as name_cls
from .field import field as field_cls
from .surface_2 import surface as surface_cls
from .zone_1 import zone as zone_cls
from .min import min as min_cls
from .max import max as max_cls
from .iso_value import iso_value as iso_value_cls

class iso_surface_child(Group):
    """
    'child_object_type' of iso_surface.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'field', 'surface', 'zone', 'min', 'max', 'iso_value']

    _child_classes = dict(
        name=name_cls,
        field=field_cls,
        surface=surface_cls,
        zone=zone_cls,
        min=min_cls,
        max=max_cls,
        iso_value=iso_value_cls,
    )

    return_type = "<object object at 0x7f7d0be09110>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .total_period_count import total_period_count as total_period_count_cls
from .time_step_count_1 import time_step_count as time_step_count_cls
from .total_time_step_count import total_time_step_count as total_time_step_count_cls
from .total_time import total_time as total_time_cls
from .incremental_time import incremental_time as incremental_time_cls
from .max_iter_per_step import max_iter_per_step as max_iter_per_step_cls
from .postprocess import postprocess as postprocess_cls
from .post_iter_per_time_step_count import post_iter_per_time_step_count as post_iter_per_time_step_count_cls

class dual_time_iterate(Command):
    """
    Perform unsteady iterations.
    
    Parameters
    ----------
        total_period_count : int
            Set number of total periods.
        time_step_count : int
            Set inceremtal number of Time steps.
        total_time_step_count : int
            Set total number of Time steps.
        total_time : real
            Set Total Simulation Time.
        incremental_time : real
            Set Incremental Time.
        max_iter_per_step : int
            Set Maximum Number of iterations per time step.
        postprocess : bool
            Enable/Disable Postprocess pollutant solution?.
        post_iter_per_time_step_count : int
            Set Number of post-processing iterations per time step.
    
    """

    fluent_name = "dual-time-iterate"

    argument_names = \
        ['total_period_count', 'time_step_count', 'total_time_step_count',
         'total_time', 'incremental_time', 'max_iter_per_step', 'postprocess',
         'post_iter_per_time_step_count']

    _child_classes = dict(
        total_period_count=total_period_count_cls,
        time_step_count=time_step_count_cls,
        total_time_step_count=total_time_step_count_cls,
        total_time=total_time_cls,
        incremental_time=incremental_time_cls,
        max_iter_per_step=max_iter_per_step_cls,
        postprocess=postprocess_cls,
        post_iter_per_time_step_count=post_iter_per_time_step_count_cls,
    )

    return_type = "<object object at 0x7f79a68d5d60>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .enable_velocity_limiting import enable_velocity_limiting as enable_velocity_limiting_cls
from .set_velocity_and_vof_cutoffs import set_velocity_and_vof_cutoffs as set_velocity_and_vof_cutoffs_cls
from .set_damping_strengths import set_damping_strengths as set_damping_strengths_cls
from .set_velocity_cutoff import set_velocity_cutoff as set_velocity_cutoff_cls
from .set_damping_strength import set_damping_strength as set_damping_strength_cls
from .verbosity_2 import verbosity as verbosity_cls

class velocity_limiting_treatment(Group):
    """
    'velocity_limiting_treatment' child.
    """

    fluent_name = "velocity-limiting-treatment"

    child_names = \
        ['enable_velocity_limiting', 'set_velocity_and_vof_cutoffs',
         'set_damping_strengths', 'set_velocity_cutoff',
         'set_damping_strength', 'verbosity']

    _child_classes = dict(
        enable_velocity_limiting=enable_velocity_limiting_cls,
        set_velocity_and_vof_cutoffs=set_velocity_and_vof_cutoffs_cls,
        set_damping_strengths=set_damping_strengths_cls,
        set_velocity_cutoff=set_velocity_cutoff_cls,
        set_damping_strength=set_damping_strength_cls,
        verbosity=verbosity_cls,
    )

    return_type = "<object object at 0x7fd5ebcfc6c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .x_velocity import x_velocity as x_velocity_cls
from .x_velocity_2 import x_velocity_2 as x_velocity_2_cls
from .y_velocity import y_velocity as y_velocity_cls
from .y_velocity_2 import y_velocity_2 as y_velocity_2_cls
from .z_velocity import z_velocity as z_velocity_cls
from .z_velocity_2 import z_velocity_2 as z_velocity_2_cls
from .magnitude import magnitude as magnitude_cls
from .swirl_fraction import swirl_fraction as swirl_fraction_cls
from .use_face_normal_direction import use_face_normal_direction as use_face_normal_direction_cls

class velocity(Group):
    fluent_name = ...
    child_names = ...
    x_velocity: x_velocity_cls = ...
    x_velocity_2: x_velocity_2_cls = ...
    y_velocity: y_velocity_cls = ...
    y_velocity_2: y_velocity_2_cls = ...
    z_velocity: z_velocity_cls = ...
    z_velocity_2: z_velocity_2_cls = ...
    magnitude: magnitude_cls = ...
    swirl_fraction: swirl_fraction_cls = ...
    use_face_normal_direction: use_face_normal_direction_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .xy_plot import xy_plot as xy_plot_cls

class plot(Group):
    """
    'plot' child.
    """

    fluent_name = "plot"

    child_names = \
        ['xy_plot']

    _child_classes = dict(
        xy_plot=xy_plot_cls,
    )

    return_type = "<object object at 0x7f7d0bd70c80>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .implicit_bodyforce_treatment import implicit_bodyforce_treatment as implicit_bodyforce_treatment_cls
from .velocity_formulation import velocity_formulation as velocity_formulation_cls
from .physical_velocity_formulation import physical_velocity_formulation as physical_velocity_formulation_cls
from .disable_rhie_chow_flux import disable_rhie_chow_flux as disable_rhie_chow_flux_cls
from .presto_pressure_scheme import presto_pressure_scheme as presto_pressure_scheme_cls
from .first_to_second_order_blending import first_to_second_order_blending as first_to_second_order_blending_cls
from .alternate_diffusion_for_porous_region_solids import alternate_diffusion_for_porous_region_solids as alternate_diffusion_for_porous_region_solids_cls

class numerics_pbns(Group):
    """
    Set numeric options.
    """

    fluent_name = "numerics-pbns"

    child_names = \
        ['implicit_bodyforce_treatment', 'velocity_formulation',
         'physical_velocity_formulation', 'disable_rhie_chow_flux',
         'presto_pressure_scheme', 'first_to_second_order_blending',
         'alternate_diffusion_for_porous_region_solids']

    _child_classes = dict(
        implicit_bodyforce_treatment=implicit_bodyforce_treatment_cls,
        velocity_formulation=velocity_formulation_cls,
        physical_velocity_formulation=physical_velocity_formulation_cls,
        disable_rhie_chow_flux=disable_rhie_chow_flux_cls,
        presto_pressure_scheme=presto_pressure_scheme_cls,
        first_to_second_order_blending=first_to_second_order_blending_cls,
        alternate_diffusion_for_porous_region_solids=alternate_diffusion_for_porous_region_solids_cls,
    )

    return_type = "<object object at 0x7f7d0bf940e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .mesh_1 import mesh as mesh_cls
from .surface_1 import surface as surface_cls
from .volume import volume as volume_cls
from .force import force as force_cls
from .lift import lift as lift_cls
from .drag import drag as drag_cls
from .moment import moment as moment_cls
from .flux_1 import flux as flux_cls
from .injection import injection as injection_cls
from .user_defined_5 import user_defined as user_defined_cls
from .aeromechanics import aeromechanics as aeromechanics_cls
from .icing import icing as icing_cls
from .expression_1 import expression as expression_cls
from .single_val_expression import single_val_expression as single_val_expression_cls
from .custom import custom as custom_cls
from .compute_1 import compute as compute_cls
from .copy_2 import copy as copy_cls
from .list import list as list_cls

class report_definitions(Group, _ChildNamedObjectAccessorMixin):
    fluent_name = ...
    child_names = ...
    mesh: mesh_cls = ...
    surface: surface_cls = ...
    volume: volume_cls = ...
    force: force_cls = ...
    lift: lift_cls = ...
    drag: drag_cls = ...
    moment: moment_cls = ...
    flux: flux_cls = ...
    injection: injection_cls = ...
    user_defined: user_defined_cls = ...
    aeromechanics: aeromechanics_cls = ...
    icing: icing_cls = ...
    expression: expression_cls = ...
    single_val_expression: single_val_expression_cls = ...
    custom: custom_cls = ...
    command_names = ...

    def compute(self, report_defs: List[str]):
        """
        'compute' command.
        
        Parameters
        ----------
            report_defs : typing.List[str]
                'report_defs' child.
        
        """

    def copy(self, copy_from: str, copy_to: str):
        """
        'copy' command.
        
        Parameters
        ----------
            copy_from : str
                'copy_from' child.
            copy_to : str
                'copy_to' child.
        
        """

    def list(self, ):
        """
        'list' command.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .load_balancing import load_balancing as load_balancing_cls
from .threshold import threshold as threshold_cls
from .interval import interval as interval_cls

class dpm_load_balancing(Group):
    """
    Enable automatic load balancing for DPM.
    """

    fluent_name = "dpm-load-balancing"

    child_names = \
        ['load_balancing', 'threshold', 'interval']

    _child_classes = dict(
        load_balancing=load_balancing_cls,
        threshold=threshold_cls,
        interval=interval_cls,
    )

    return_type = "<object object at 0x7f7d0bcbc260>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .initialize_1 import initialize as initialize_cls
from .duplicate import duplicate as duplicate_cls
from .set_as_current import set_as_current as set_as_current_cls
from .use_base_data import use_base_data as use_base_data_cls
from .export_design_table import export_design_table as export_design_table_cls
from .import_design_table import import_design_table as import_design_table_cls
from .parametric_studies_child import parametric_studies_child


class parametric_studies(NamedObject[parametric_studies_child], CreatableNamedObjectMixin[parametric_studies_child]):
    fluent_name = ...
    command_names = ...

    def initialize(self, project_filename: str):
        """
        Start Parametric Study.
        
        Parameters
        ----------
            project_filename : str
                'project_filename' child.
        
        """

    def duplicate(self, copy_design_points: bool):
        """
        Duplicate Parametric Study.
        
        Parameters
        ----------
            copy_design_points : bool
                'copy_design_points' child.
        
        """

    def set_as_current(self, study_name: str):
        """
        Set As Current Study.
        
        Parameters
        ----------
            study_name : str
                'study_name' child.
        
        """

    def use_base_data(self, ):
        """
        Use Base Data.
        """

    def export_design_table(self, filepath: str):
        """
        Export Design Point Table.
        
        Parameters
        ----------
            filepath : str
                'filepath' child.
        
        """

    def import_design_table(self, filepath: str, delete_existing: bool):
        """
        Import Design Point Table.
        
        Parameters
        ----------
            filepath : str
                'filepath' child.
            delete_existing : bool
                'delete_existing' child.
        
        """

    child_object_type = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .option_3 import option as option_cls
from .c1 import c1 as c1_cls
from .c2 import c2 as c2_cls
from .reference_viscosity import reference_viscosity as reference_viscosity_cls
from .reference_temperature import reference_temperature as reference_temperature_cls
from .effective_temperature import effective_temperature as effective_temperature_cls

class sutherland(Group):
    fluent_name = ...
    child_names = ...
    option: option_cls = ...
    c1: c1_cls = ...
    c2: c2_cls = ...
    reference_viscosity: reference_viscosity_cls = ...
    reference_temperature: reference_temperature_cls = ...
    effective_temperature: effective_temperature_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .load_balancing import load_balancing as load_balancing_cls
from .threshold import threshold as threshold_cls
from .interval import interval as interval_cls

class dpm_load_balancing(Group):
    fluent_name = ...
    child_names = ...
    load_balancing: load_balancing_cls = ...
    threshold: threshold_cls = ...
    interval: interval_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .across_zone_boundaries import across_zone_boundaries as across_zone_boundaries_cls

class across_zones(Command):
    """
    Enable partitioning by zone or by domain.
    
    Parameters
    ----------
        across_zone_boundaries : bool
            'across_zone_boundaries' child.
    
    """

    fluent_name = "across-zones"

    argument_names = \
        ['across_zone_boundaries']

    _child_classes = dict(
        across_zone_boundaries=across_zone_boundaries_cls,
    )

    return_type = "<object object at 0x7f7d0bcbc280>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .node_values_1 import node_values as node_values_cls

class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['node_values']

    _child_classes = dict(
        node_values=node_values_cls,
    )

    return_type = "<object object at 0x7f7d0bdc1e70>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .options_1 import options as options_cls
from .convert_domain import convert_domain as convert_domain_cls
from .convert_hanging_nodes import convert_hanging_nodes as convert_hanging_nodes_cls
from .convert_hanging_node_zones import convert_hanging_node_zones as convert_hanging_node_zones_cls
from .convert_skewed_cells_1 import convert_skewed_cells as convert_skewed_cells_cls

class polyhedra(Group):
    """
    Enter the polyhedra menu.
    """

    fluent_name = "polyhedra"

    child_names = \
        ['options']

    command_names = \
        ['convert_domain', 'convert_hanging_nodes',
         'convert_hanging_node_zones', 'convert_skewed_cells']

    _child_classes = dict(
        options=options_cls,
        convert_domain=convert_domain_cls,
        convert_hanging_nodes=convert_hanging_nodes_cls,
        convert_hanging_node_zones=convert_hanging_node_zones_cls,
        convert_skewed_cells=convert_skewed_cells_cls,
    )

    return_type = "<object object at 0x7f7d7fb8e340>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .auto_range_1 import auto_range as auto_range_cls
from .correlation import correlation as correlation_cls
from .cumulation_curve import cumulation_curve as cumulation_curve_cls
from .diameter_statistics import diameter_statistics as diameter_statistics_cls
from .histogram_mode import histogram_mode as histogram_mode_cls
from .percentage import percentage as percentage_cls
from .variable_3 import variable_3 as variable_3_cls
from .logarithmic import logarithmic as logarithmic_cls
from .weighting import weighting as weighting_cls

class histogram_options(Group):
    fluent_name = ...
    child_names = ...
    auto_range: auto_range_cls = ...
    correlation: correlation_cls = ...
    cumulation_curve: cumulation_curve_cls = ...
    diameter_statistics: diameter_statistics_cls = ...
    histogram_mode: histogram_mode_cls = ...
    percentage: percentage_cls = ...
    variable_3: variable_3_cls = ...
    logarithmic: logarithmic_cls = ...
    weighting: weighting_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .spatial_discretization_limiter import spatial_discretization_limiter as spatial_discretization_limiter_cls
from .pseudo_time_method_usage import pseudo_time_method_usage as pseudo_time_method_usage_cls

class expert(Group):
    """
    'expert' child.
    """

    fluent_name = "expert"

    child_names = \
        ['spatial_discretization_limiter', 'pseudo_time_method_usage']

    _child_classes = dict(
        spatial_discretization_limiter=spatial_discretization_limiter_cls,
        pseudo_time_method_usage=pseudo_time_method_usage_cls,
    )

    return_type = "<object object at 0x7f7d0bf5adf0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .min_point import min_point as min_point_cls
from .max_point import max_point as max_point_cls
from .inside import inside as inside_cls
from .create_volume_surface import create_volume_surface as create_volume_surface_cls

class hexahedron(Group):
    fluent_name = ...
    child_names = ...
    min_point: min_point_cls = ...
    max_point: max_point_cls = ...
    inside: inside_cls = ...
    create_volume_surface: create_volume_surface_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .option_3 import option as option_cls
from .hexahedron import hexahedron as hexahedron_cls
from .sphere import sphere as sphere_cls
from .cylinder import cylinder as cylinder_cls
from .boundary import boundary as boundary_cls
from .limiters import limiters as limiters_cls
from .field_value import field_value as field_value_cls
from .residual import residual as residual_cls
from .volume_1 import volume as volume_cls
from .yplus_star import yplus_star as yplus_star_cls
from .yplus_ystar import yplus_ystar as yplus_ystar_cls

class type(Group):
    fluent_name = ...
    child_names = ...
    option: option_cls = ...
    hexahedron: hexahedron_cls = ...
    sphere: sphere_cls = ...
    cylinder: cylinder_cls = ...
    boundary: boundary_cls = ...
    limiters: limiters_cls = ...
    field_value: field_value_cls = ...
    residual: residual_cls = ...
    volume: volume_cls = ...
    yplus_star: yplus_star_cls = ...
    yplus_ystar: yplus_ystar_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .enabled_2 import enabled as enabled_cls
from .user_defined_timestep import user_defined_timestep as user_defined_timestep_cls
from .error_tolerance import error_tolerance as error_tolerance_cls
from .time_end import time_end as time_end_cls
from .min_time_step import min_time_step as min_time_step_cls
from .max_time_step import max_time_step as max_time_step_cls
from .min_step_change_factor import min_step_change_factor as min_step_change_factor_cls
from .max_step_change_factor import max_step_change_factor as max_step_change_factor_cls
from .fixed_time_step_count import fixed_time_step_count as fixed_time_step_count_cls

class adaptive_time_stepping(Group):
    """
    'adaptive_time_stepping' child.
    """

    fluent_name = "adaptive-time-stepping"

    child_names = \
        ['enabled', 'user_defined_timestep', 'error_tolerance', 'time_end',
         'min_time_step', 'max_time_step', 'min_step_change_factor',
         'max_step_change_factor', 'fixed_time_step_count']

    _child_classes = dict(
        enabled=enabled_cls,
        user_defined_timestep=user_defined_timestep_cls,
        error_tolerance=error_tolerance_cls,
        time_end=time_end_cls,
        min_time_step=min_time_step_cls,
        max_time_step=max_time_step_cls,
        min_step_change_factor=min_step_change_factor_cls,
        max_step_change_factor=max_step_change_factor_cls,
        fixed_time_step_count=fixed_time_step_count_cls,
    )

    return_type = "<object object at 0x7f79a68d5520>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option import option as option_cls
from .constant import constant as constant_cls
from .profile_name import profile_name as profile_name_cls
from .field_name import field_name as field_name_cls
from .udf import udf as udf_cls

class pollut_ctar(Group):
    """
    'pollut_ctar' child.
    """

    fluent_name = "pollut-ctar"

    child_names = \
        ['option', 'constant', 'profile_name', 'field_name', 'udf']

    _child_classes = dict(
        option=option_cls,
        constant=constant_cls,
        profile_name=profile_name_cls,
        field_name=field_name_cls,
        udf=udf_cls,
    )

    return_type = "<object object at 0x7fd5ecdaf7e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .matrix_component import matrix_component as matrix_component_cls
from .diffusivity import diffusivity as diffusivity_cls

class anisotropic(Group):
    """
    'anisotropic' child.
    """

    fluent_name = "anisotropic"

    child_names = \
        ['matrix_component', 'diffusivity']

    _child_classes = dict(
        matrix_component=matrix_component_cls,
        diffusivity=diffusivity_cls,
    )

    return_type = "<object object at 0x7fabc47ab7b0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .max_coarse_levels_2 import max_coarse_levels as max_coarse_levels_cls
from .coarsen_by_interval_2 import coarsen_by_interval as coarsen_by_interval_cls

class coarsening_parameters(Group):
    fluent_name = ...
    child_names = ...
    max_coarse_levels: max_coarse_levels_cls = ...
    coarsen_by_interval: coarsen_by_interval_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .fixed_cycle_parameters_2 import fixed_cycle_parameters as fixed_cycle_parameters_cls
from .coarsening_parameters_2 import coarsening_parameters as coarsening_parameters_cls
from .relaxation_factor import relaxation_factor as relaxation_factor_cls
from .options_1 import options as options_cls

class fas_mg_controls(Group):
    """
    'fas_mg_controls' child.
    """

    fluent_name = "fas-mg-controls"

    child_names = \
        ['fixed_cycle_parameters', 'coarsening_parameters',
         'relaxation_factor', 'options']

    _child_classes = dict(
        fixed_cycle_parameters=fixed_cycle_parameters_cls,
        coarsening_parameters=coarsening_parameters_cls,
        relaxation_factor=relaxation_factor_cls,
        options=options_cls,
    )

    return_type = "<object object at 0x7fd5ebd34570>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .phase_1 import phase as phase_cls
from .material_1 import material as material_cls
from .sources import sources as sources_cls
from .source_terms_1 import source_terms as source_terms_cls
from .fixed import fixed as fixed_cls
from .cylindrical_fixed_var import cylindrical_fixed_var as cylindrical_fixed_var_cls
from .fixes import fixes as fixes_cls
from .motion_spec import motion_spec as motion_spec_cls
from .relative_to_thread import relative_to_thread as relative_to_thread_cls
from .omega import omega as omega_cls
from .axis_origin_1 import axis_origin as axis_origin_cls
from .axis_direction_1 import axis_direction as axis_direction_cls
from .udf_zmotion_name import udf_zmotion_name as udf_zmotion_name_cls
from .mrf_motion import mrf_motion as mrf_motion_cls
from .mrf_relative_to_thread import mrf_relative_to_thread as mrf_relative_to_thread_cls
from .mrf_omega import mrf_omega as mrf_omega_cls
from .reference_frame_velocity import reference_frame_velocity as reference_frame_velocity_cls
from .reference_frame_axis_origin import reference_frame_axis_origin as reference_frame_axis_origin_cls
from .reference_frame_axis_direction import reference_frame_axis_direction as reference_frame_axis_direction_cls
from .mrf_udf_zmotion_name import mrf_udf_zmotion_name as mrf_udf_zmotion_name_cls
from .mgrid_enable_transient import mgrid_enable_transient as mgrid_enable_transient_cls
from .mgrid_motion import mgrid_motion as mgrid_motion_cls
from .mgrid_relative_to_thread import mgrid_relative_to_thread as mgrid_relative_to_thread_cls
from .mgrid_omega import mgrid_omega as mgrid_omega_cls
from .moving_mesh_velocity import moving_mesh_velocity as moving_mesh_velocity_cls
from .moving_mesh_axis_origin import moving_mesh_axis_origin as moving_mesh_axis_origin_cls
from .moving_mesh_axis_direction import moving_mesh_axis_direction as moving_mesh_axis_direction_cls
from .mgrid_udf_zmotion_name import mgrid_udf_zmotion_name as mgrid_udf_zmotion_name_cls
from .solid_motion import solid_motion as solid_motion_cls
from .solid_relative_to_thread import solid_relative_to_thread as solid_relative_to_thread_cls
from .solid_omega import solid_omega as solid_omega_cls
from .solid_motion_velocity import solid_motion_velocity as solid_motion_velocity_cls
from .solid_motion_axis_origin import solid_motion_axis_origin as solid_motion_axis_origin_cls
from .solid_motion_axis_direction import solid_motion_axis_direction as solid_motion_axis_direction_cls
from .solid_udf_zmotion_name import solid_udf_zmotion_name as solid_udf_zmotion_name_cls
from .radiating import radiating as radiating_cls
from .les_embedded import les_embedded as les_embedded_cls
from .contact_property import contact_property as contact_property_cls
from .active_wetsteam_zone import active_wetsteam_zone as active_wetsteam_zone_cls
from .vapor_phase_realgas import vapor_phase_realgas as vapor_phase_realgas_cls
from .cursys import cursys as cursys_cls
from .cursys_name import cursys_name as cursys_name_cls
from .pcb_model import pcb_model as pcb_model_cls
from .pcb_zone_info import pcb_zone_info as pcb_zone_info_cls

class solid_child(Group):
    """
    'child_object_type' of solid.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'material', 'sources', 'source_terms', 'fixed',
         'cylindrical_fixed_var', 'fixes', 'motion_spec',
         'relative_to_thread', 'omega', 'axis_origin', 'axis_direction',
         'udf_zmotion_name', 'mrf_motion', 'mrf_relative_to_thread',
         'mrf_omega', 'reference_frame_velocity',
         'reference_frame_axis_origin', 'reference_frame_axis_direction',
         'mrf_udf_zmotion_name', 'mgrid_enable_transient', 'mgrid_motion',
         'mgrid_relative_to_thread', 'mgrid_omega', 'moving_mesh_velocity',
         'moving_mesh_axis_origin', 'moving_mesh_axis_direction',
         'mgrid_udf_zmotion_name', 'solid_motion', 'solid_relative_to_thread',
         'solid_omega', 'solid_motion_velocity', 'solid_motion_axis_origin',
         'solid_motion_axis_direction', 'solid_udf_zmotion_name', 'radiating',
         'les_embedded', 'contact_property', 'active_wetsteam_zone',
         'vapor_phase_realgas', 'cursys', 'cursys_name', 'pcb_model',
         'pcb_zone_info']

    _child_classes = dict(
        phase=phase_cls,
        material=material_cls,
        sources=sources_cls,
        source_terms=source_terms_cls,
        fixed=fixed_cls,
        cylindrical_fixed_var=cylindrical_fixed_var_cls,
        fixes=fixes_cls,
        motion_spec=motion_spec_cls,
        relative_to_thread=relative_to_thread_cls,
        omega=omega_cls,
        axis_origin=axis_origin_cls,
        axis_direction=axis_direction_cls,
        udf_zmotion_name=udf_zmotion_name_cls,
        mrf_motion=mrf_motion_cls,
        mrf_relative_to_thread=mrf_relative_to_thread_cls,
        mrf_omega=mrf_omega_cls,
        reference_frame_velocity=reference_frame_velocity_cls,
        reference_frame_axis_origin=reference_frame_axis_origin_cls,
        reference_frame_axis_direction=reference_frame_axis_direction_cls,
        mrf_udf_zmotion_name=mrf_udf_zmotion_name_cls,
        mgrid_enable_transient=mgrid_enable_transient_cls,
        mgrid_motion=mgrid_motion_cls,
        mgrid_relative_to_thread=mgrid_relative_to_thread_cls,
        mgrid_omega=mgrid_omega_cls,
        moving_mesh_velocity=moving_mesh_velocity_cls,
        moving_mesh_axis_origin=moving_mesh_axis_origin_cls,
        moving_mesh_axis_direction=moving_mesh_axis_direction_cls,
        mgrid_udf_zmotion_name=mgrid_udf_zmotion_name_cls,
        solid_motion=solid_motion_cls,
        solid_relative_to_thread=solid_relative_to_thread_cls,
        solid_omega=solid_omega_cls,
        solid_motion_velocity=solid_motion_velocity_cls,
        solid_motion_axis_origin=solid_motion_axis_origin_cls,
        solid_motion_axis_direction=solid_motion_axis_direction_cls,
        solid_udf_zmotion_name=solid_udf_zmotion_name_cls,
        radiating=radiating_cls,
        les_embedded=les_embedded_cls,
        contact_property=contact_property_cls,
        active_wetsteam_zone=active_wetsteam_zone_cls,
        vapor_phase_realgas=vapor_phase_realgas_cls,
        cursys=cursys_cls,
        cursys_name=cursys_name_cls,
        pcb_model=pcb_model_cls,
        pcb_zone_info=pcb_zone_info_cls,
    )

    return_type = "<object object at 0x7f79c86457b0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class unstructured_var_presto_scheme(Boolean):
    """
    Enable/disable use of unstructured variant of PRESTO pressure scheme.
    """

    fluent_name = "unstructured-var-presto-scheme?"

    return_type = "<object object at 0x7f79a695a0b0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .convergence_reports import convergence_reports as convergence_reports_cls
from .frequency_1 import frequency as frequency_cls
from .condition import condition as condition_cls
from .check_for import check_for as check_for_cls

class convergence_conditions(Group):
    """
    'convergence_conditions' child.
    """

    fluent_name = "convergence-conditions"

    child_names = \
        ['convergence_reports', 'frequency', 'condition', 'check_for']

    _child_classes = dict(
        convergence_reports=convergence_reports_cls,
        frequency=frequency_cls,
        condition=condition_cls,
        check_for=check_for_cls,
    )

    return_type = "<object object at 0x7f7d0bed6c00>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .write_data import write_data as write_data_cls
from .capture_simulation_report_data import capture_simulation_report_data as capture_simulation_report_data_cls

class create_1(Command):
    """
    Add new Design Point.
    
    Parameters
    ----------
        write_data : bool
            'write_data' child.
        capture_simulation_report_data : bool
            'capture_simulation_report_data' child.
    
    """

    fluent_name = "create"

    argument_names = \
        ['write_data', 'capture_simulation_report_data']

    _child_classes = dict(
        write_data=write_data_cls,
        capture_simulation_report_data=capture_simulation_report_data_cls,
    )

    return_type = "<object object at 0x7f7d0bcf6af0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .zone1_1 import zone1 as zone1_cls
from .zone2_1 import zone2 as zone2_cls
from .pitch_change_types import pitch_change_types as pitch_change_types_cls
from .mixing_plane import mixing_plane as mixing_plane_cls
from .turbo_non_overlap import turbo_non_overlap as turbo_non_overlap_cls

class turbo_interface_child(Group):
    fluent_name = ...
    child_names = ...
    zone1: zone1_cls = ...
    zone2: zone2_cls = ...
    pitch_change_types: pitch_change_types_cls = ...
    mixing_plane: mixing_plane_cls = ...
    turbo_non_overlap: turbo_non_overlap_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .density_5 import density as density_cls
from .specific_heat_4 import specific_heat as specific_heat_cls
from .species import species as species_cls
from .vp_equilib import vp_equilib as vp_equilib_cls
from .thermal_conductivity_3 import thermal_conductivity as thermal_conductivity_cls
from .viscosity_2 import viscosity as viscosity_cls
from .dpm_surften import dpm_surften as dpm_surften_cls
from .emissivity_2 import emissivity as emissivity_cls
from .scattering_factor_2 import scattering_factor as scattering_factor_cls
from .vaporization_model import vaporization_model as vaporization_model_cls
from .averaging_coefficient_t import averaging_coefficient_t as averaging_coefficient_t_cls
from .averaging_coefficient_y import averaging_coefficient_y as averaging_coefficient_y_cls
from .thermophoretic_co import thermophoretic_co as thermophoretic_co_cls
from .reaction_model import reaction_model as reaction_model_cls
from .mixture_species_1 import mixture_species as mixture_species_cls

class particle_mixture_child(Group):
    """
    'child_object_type' of particle_mixture.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['density', 'specific_heat', 'species', 'vp_equilib',
         'thermal_conductivity', 'viscosity', 'dpm_surften', 'emissivity',
         'scattering_factor', 'vaporization_model', 'averaging_coefficient_t',
         'averaging_coefficient_y', 'thermophoretic_co', 'reaction_model',
         'mixture_species']

    _child_classes = dict(
        density=density_cls,
        specific_heat=specific_heat_cls,
        species=species_cls,
        vp_equilib=vp_equilib_cls,
        thermal_conductivity=thermal_conductivity_cls,
        viscosity=viscosity_cls,
        dpm_surften=dpm_surften_cls,
        emissivity=emissivity_cls,
        scattering_factor=scattering_factor_cls,
        vaporization_model=vaporization_model_cls,
        averaging_coefficient_t=averaging_coefficient_t_cls,
        averaging_coefficient_y=averaging_coefficient_y_cls,
        thermophoretic_co=thermophoretic_co_cls,
        reaction_model=reaction_model_cls,
        mixture_species=mixture_species_cls,
    )

    return_type = "<object object at 0x7f79c826bd40>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_3 import option as option_cls
from .direction_vector_2 import direction_vector as direction_vector_cls
from .curve_length import curve_length as curve_length_cls

class plot_direction(Group):
    """
    'plot_direction' child.
    """

    fluent_name = "plot-direction"

    child_names = \
        ['option', 'direction_vector', 'curve_length']

    _child_classes = dict(
        option=option_cls,
        direction_vector=direction_vector_cls,
        curve_length=curve_length_cls,
    )

    return_type = "<object object at 0x7f79a67c8fc0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .angle import angle as angle_cls
from .origin import origin as origin_cls
from .axis_components import axis_components as axis_components_cls

class rotate(Command):
    fluent_name = ...
    argument_names = ...
    angle: angle_cls = ...
    origin: origin_cls = ...
    axis_components: axis_components_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .cell_function_1 import cell_function as cell_function_cls
from .load_distribution import load_distribution as load_distribution_cls
from .merge import merge as merge_cls
from .partition_origin_vector import partition_origin_vector as partition_origin_vector_cls
from .pre_test_1 import pre_test as pre_test_cls
from .smooth_1 import smooth as smooth_cls
from .print_verbosity import print_verbosity as print_verbosity_cls
from .origin import origin as origin_cls
from .laplace_smoothing import laplace_smoothing as laplace_smoothing_cls
from .nfaces_as_weights_1 import nfaces_as_weights as nfaces_as_weights_cls
from .face_area_as_weights import face_area_as_weights as face_area_as_weights_cls
from .layering import layering as layering_cls
from .solid_thread_weight import solid_thread_weight as solid_thread_weight_cls
from .stretched_mesh_enhancement import stretched_mesh_enhancement as stretched_mesh_enhancement_cls
from .particle_weight import particle_weight as particle_weight_cls
from .vof_free_surface_weight import vof_free_surface_weight as vof_free_surface_weight_cls
from .isat_weight import isat_weight as isat_weight_cls
from .fluid_solid_rebalance_after_read_case import fluid_solid_rebalance_after_read_case as fluid_solid_rebalance_after_read_case_cls
from .model_weighted_partition import model_weighted_partition as model_weighted_partition_cls
from .dpm_load_balancing import dpm_load_balancing as dpm_load_balancing_cls
from .across_zones_1 import across_zones as across_zones_cls
from .all_off import all_off as all_off_cls
from .all_on import all_on as all_on_cls

class set(Group):
    """
    Enter the menu to set partition parameters.
    """

    fluent_name = "set"

    child_names = \
        ['cell_function', 'load_distribution', 'merge',
         'partition_origin_vector', 'pre_test', 'smooth', 'print_verbosity',
         'origin', 'laplace_smoothing', 'nfaces_as_weights',
         'face_area_as_weights', 'layering', 'solid_thread_weight',
         'stretched_mesh_enhancement', 'particle_weight',
         'vof_free_surface_weight', 'isat_weight',
         'fluid_solid_rebalance_after_read_case', 'model_weighted_partition',
         'dpm_load_balancing']

    command_names = \
        ['across_zones', 'all_off', 'all_on']

    _child_classes = dict(
        cell_function=cell_function_cls,
        load_distribution=load_distribution_cls,
        merge=merge_cls,
        partition_origin_vector=partition_origin_vector_cls,
        pre_test=pre_test_cls,
        smooth=smooth_cls,
        print_verbosity=print_verbosity_cls,
        origin=origin_cls,
        laplace_smoothing=laplace_smoothing_cls,
        nfaces_as_weights=nfaces_as_weights_cls,
        face_area_as_weights=face_area_as_weights_cls,
        layering=layering_cls,
        solid_thread_weight=solid_thread_weight_cls,
        stretched_mesh_enhancement=stretched_mesh_enhancement_cls,
        particle_weight=particle_weight_cls,
        vof_free_surface_weight=vof_free_surface_weight_cls,
        isat_weight=isat_weight_cls,
        fluid_solid_rebalance_after_read_case=fluid_solid_rebalance_after_read_case_cls,
        model_weighted_partition=model_weighted_partition_cls,
        dpm_load_balancing=dpm_load_balancing_cls,
        across_zones=across_zones_cls,
        all_off=all_off_cls,
        all_on=all_on_cls,
    )

    return_type = "<object object at 0x7f79a670e320>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .filename import filename as filename_cls
from .unit import unit as unit_cls

class read(Command):
    """
    Read surface meshes.
    
    Parameters
    ----------
        filename : str
            'filename' child.
        unit : str
            'unit' child.
    
    """

    fluent_name = "read"

    argument_names = \
        ['filename', 'unit']

    _child_classes = dict(
        filename=filename_cls,
        unit=unit_cls,
    )

    return_type = "<object object at 0x7f7d7fb8e270>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option import option as option_cls
from .c1 import c1 as c1_cls
from .c2 import c2 as c2_cls
from .reference_viscosity import reference_viscosity as reference_viscosity_cls
from .reference_temperature import reference_temperature as reference_temperature_cls
from .effective_temperature import effective_temperature as effective_temperature_cls

class sutherland(Group):
    """
    'sutherland' child.
    """

    fluent_name = "sutherland"

    child_names = \
        ['option', 'c1', 'c2', 'reference_viscosity', 'reference_temperature',
         'effective_temperature']

    _child_classes = dict(
        option=option_cls,
        c1=c1_cls,
        c2=c2_cls,
        reference_viscosity=reference_viscosity_cls,
        reference_temperature=reference_temperature_cls,
        effective_temperature=effective_temperature_cls,
    )

    return_type = "<object object at 0x7f7d7fef3650>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .outer_iterations import outer_iterations as outer_iterations_cls
from .initial_outer_iterations import initial_outer_iterations as initial_outer_iterations_cls
from .instability_detector import instability_detector as instability_detector_cls

class hybrid_nita(Group):
    fluent_name = ...
    child_names = ...
    outer_iterations: outer_iterations_cls = ...
    initial_outer_iterations: initial_outer_iterations_cls = ...
    instability_detector: instability_detector_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class first_to_second_order_blending(Real):
    """
    1st-order to higher-order blending factor [min=0.0 - max=1.0].
    """

    fluent_name = "first-to-second-order-blending"

    return_type = "<object object at 0x7f79a6990570>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .solution_controls import solution_controls as solution_controls_cls
from .amg_controls import amg_controls as amg_controls_cls
from .multi_stage_parameter import multi_stage_parameter as multi_stage_parameter_cls
from .limits_1 import limits as limits_cls
from .reset_pseudo_time_method_generic import reset_pseudo_time_method_generic as reset_pseudo_time_method_generic_cls
from .reset_pseudo_time_method_equations import reset_pseudo_time_method_equations as reset_pseudo_time_method_equations_cls
from .reset_pseudo_time_method_relaxations import reset_pseudo_time_method_relaxations as reset_pseudo_time_method_relaxations_cls
from .reset_pseudo_time_method_scale_factors import reset_pseudo_time_method_scale_factors as reset_pseudo_time_method_scale_factors_cls

class set_controls_to_default(Group):
    fluent_name = ...
    command_names = ...

    def solution_controls(self, ):
        """
        'solution_controls' command.
        """

    def amg_controls(self, ):
        """
        'amg_controls' command.
        """

    def multi_stage_parameter(self, ):
        """
        'multi_stage_parameter' command.
        """

    def limits(self, ):
        """
        'limits' command.
        """

    def reset_pseudo_time_method_generic(self, ):
        """
        'reset_pseudo_time_method_generic' command.
        """

    def reset_pseudo_time_method_equations(self, ):
        """
        'reset_pseudo_time_method_equations' command.
        """

    def reset_pseudo_time_method_relaxations(self, ):
        """
        'reset_pseudo_time_method_relaxations' command.
        """

    def reset_pseudo_time_method_scale_factors(self, ):
        """
        'reset_pseudo_time_method_scale_factors' command.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_10 import option as option_cls
from .neutral_involved_interaction import neutral_involved_interaction as neutral_involved_interaction_cls
from .charged_particle_interaction import charged_particle_interaction as charged_particle_interaction_cls

class child_object_type_child(Group):
    """
    'child_object_type' of child_object_type.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['option', 'neutral_involved_interaction',
         'charged_particle_interaction']

    _child_classes = dict(
        option=option_cls,
        neutral_involved_interaction=neutral_involved_interaction_cls,
        charged_particle_interaction=charged_particle_interaction_cls,
    )

    return_type = "<object object at 0x7f79c87f6630>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enable_volumetric_reactions import enable_volumetric_reactions as enable_volumetric_reactions_cls
from .enable_wall_surface import enable_wall_surface as enable_wall_surface_cls
from .enable_particle_surface import enable_particle_surface as enable_particle_surface_cls
from .enable_electrochemical_surface import enable_electrochemical_surface as enable_electrochemical_surface_cls

class reactions(Group):
    fluent_name = ...
    child_names = ...
    enable_volumetric_reactions: enable_volumetric_reactions_cls = ...
    enable_wall_surface: enable_wall_surface_cls = ...
    enable_particle_surface: enable_particle_surface_cls = ...
    enable_electrochemical_surface: enable_electrochemical_surface_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name_2 import name as name_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .porous_jump_turb_wall_treatment import porous_jump_turb_wall_treatment as porous_jump_turb_wall_treatment_cls
from .alpha import alpha as alpha_cls
from .dm import dm as dm_cls
from .c2_1 import c2 as c2_cls
from .thermal_ctk import thermal_ctk as thermal_ctk_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .v_absp import v_absp as v_absp_cls
from .ir_absp import ir_absp as ir_absp_cls
from .ir_trans import ir_trans as ir_trans_cls
from .v_trans import v_trans as v_trans_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .strength import strength as strength_cls
from .jump_adhesion import jump_adhesion as jump_adhesion_cls
from .adhesion_constrained import adhesion_constrained as adhesion_constrained_cls
from .adhesion_angle import adhesion_angle as adhesion_angle_cls
from .x_displacement_type import x_displacement_type as x_displacement_type_cls
from .x_displacement_value import x_displacement_value as x_displacement_value_cls
from .y_displacement_type import y_displacement_type as y_displacement_type_cls
from .y_displacement_value import y_displacement_value as y_displacement_value_cls
from .z_displacement_type import z_displacement_type as z_displacement_type_cls
from .z_displacement_value import z_displacement_value as z_displacement_value_cls

class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread',
         'porous_jump_turb_wall_treatment', 'alpha', 'dm', 'c2',
         'thermal_ctk', 'solar_fluxes', 'v_absp', 'ir_absp', 'ir_trans',
         'v_trans', 'dpm_bc_type', 'dpm_bc_collision_partner', 'reinj_inj',
         'dpm_bc_udf', 'strength', 'jump_adhesion', 'adhesion_constrained',
         'adhesion_angle', 'x_displacement_type', 'x_displacement_value',
         'y_displacement_type', 'y_displacement_value', 'z_displacement_type',
         'z_displacement_value']

    _child_classes = dict(
        name=name_cls,
        geom_disable=geom_disable_cls,
        geom_dir_spec=geom_dir_spec_cls,
        geom_dir_x=geom_dir_x_cls,
        geom_dir_y=geom_dir_y_cls,
        geom_dir_z=geom_dir_z_cls,
        geom_levels=geom_levels_cls,
        geom_bgthread=geom_bgthread_cls,
        porous_jump_turb_wall_treatment=porous_jump_turb_wall_treatment_cls,
        alpha=alpha_cls,
        dm=dm_cls,
        c2=c2_cls,
        thermal_ctk=thermal_ctk_cls,
        solar_fluxes=solar_fluxes_cls,
        v_absp=v_absp_cls,
        ir_absp=ir_absp_cls,
        ir_trans=ir_trans_cls,
        v_trans=v_trans_cls,
        dpm_bc_type=dpm_bc_type_cls,
        dpm_bc_collision_partner=dpm_bc_collision_partner_cls,
        reinj_inj=reinj_inj_cls,
        dpm_bc_udf=dpm_bc_udf_cls,
        strength=strength_cls,
        jump_adhesion=jump_adhesion_cls,
        adhesion_constrained=adhesion_constrained_cls,
        adhesion_angle=adhesion_angle_cls,
        x_displacement_type=x_displacement_type_cls,
        x_displacement_value=x_displacement_value_cls,
        y_displacement_type=y_displacement_type_cls,
        y_displacement_value=y_displacement_value_cls,
        z_displacement_type=z_displacement_type_cls,
        z_displacement_value=z_displacement_value_cls,
    )

    return_type = "<object object at 0x7f7d742942a0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .flux_auto_select import flux_auto_select as flux_auto_select_cls
from .flux_type_1 import flux_type as flux_type_cls

class pbns_cases(Group):
    fluent_name = ...
    child_names = ...
    flux_auto_select: flux_auto_select_cls = ...
    flux_type: flux_type_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .pole_real import pole_real as pole_real_cls
from .pole_imag import pole_imag as pole_imag_cls
from .amplitude_real import amplitude_real as amplitude_real_cls
from .amplitude_imag import amplitude_imag as amplitude_imag_cls

class impedance_2_child(Group):
    fluent_name = ...
    child_names = ...
    pole_real: pole_real_cls = ...
    pole_imag: pole_imag_cls = ...
    amplitude_real: amplitude_real_cls = ...
    amplitude_imag: amplitude_imag_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .start_frame import start_frame as start_frame_cls
from .end_frame import end_frame as end_frame_cls
from .increment import increment as increment_cls

class set_custom_frames(Group):
    fluent_name = ...
    child_names = ...
    start_frame: start_frame_cls = ...
    end_frame: end_frame_cls = ...
    increment: increment_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enalbled import enalbled as enalbled_cls
from .user_defined_timestep import user_defined_timestep as user_defined_timestep_cls
from .desired_cfl import desired_cfl as desired_cfl_cls
from .time_end import time_end as time_end_cls
from .initial_time_step import initial_time_step as initial_time_step_cls
from .max_fixed_time_step import max_fixed_time_step as max_fixed_time_step_cls
from .update_interval_time_step_size import update_interval_time_step_size as update_interval_time_step_size_cls
from .min_time_step import min_time_step as min_time_step_cls
from .max_time_step import max_time_step as max_time_step_cls
from .min_step_change_factor import min_step_change_factor as min_step_change_factor_cls
from .max_step_change_factor import max_step_change_factor as max_step_change_factor_cls

class cfl_based_adaptive_time_stepping(Group):
    fluent_name = ...
    child_names = ...
    enalbled: enalbled_cls = ...
    user_defined_timestep: user_defined_timestep_cls = ...
    desired_cfl: desired_cfl_cls = ...
    time_end: time_end_cls = ...
    initial_time_step: initial_time_step_cls = ...
    max_fixed_time_step: max_fixed_time_step_cls = ...
    update_interval_time_step_size: update_interval_time_step_size_cls = ...
    min_time_step: min_time_step_cls = ...
    max_time_step: max_time_step_cls = ...
    min_step_change_factor: min_step_change_factor_cls = ...
    max_step_change_factor: max_step_change_factor_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .enable_4 import enable as enable_cls
from .mode import mode as mode_cls
from .disk import disk as disk_cls

class virtual_blade_model(Group):
    """
    Enter the vbm model menu.
    """

    fluent_name = "virtual-blade-model"

    child_names = \
        ['enable', 'mode', 'disk']

    _child_classes = dict(
        enable=enable_cls,
        mode=mode_cls,
        disk=disk_cls,
    )

    return_type = "<object object at 0x7f79c85d9d90>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .enable_turb_damping import enable_turb_damping as enable_turb_damping_cls
from .turb_damping_factor import turb_damping_factor as turb_damping_factor_cls

class turbulence_damping(Group):
    """
    'turbulence_damping' child.
    """

    fluent_name = "turbulence-damping"

    child_names = \
        ['enable_turb_damping', 'turb_damping_factor']

    _child_classes = dict(
        enable_turb_damping=enable_turb_damping_cls,
        turb_damping_factor=turb_damping_factor_cls,
    )

    return_type = "<object object at 0x7f79c85d9550>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .list_properties_1 import list_properties as list_properties_cls
from .piecewise_polynomial_child import piecewise_polynomial_child


class piecewise_polynomial(ListObject[piecewise_polynomial_child]):
    """
    'piecewise_polynomial' child.
    """

    fluent_name = "piecewise-polynomial"

    command_names = \
        ['list_properties']

    _child_classes = dict(
        list_properties=list_properties_cls,
    )

    child_object_type: piecewise_polynomial_child = piecewise_polynomial_child
    """
    child_object_type of piecewise_polynomial.
    """
    return_type = "<object object at 0x7f7d7fef3260>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .cell_zone_list import cell_zone_list as cell_zone_list_cls

class activate_cell_zone(Command):
    """
    Activate a cell thread.
    
    Parameters
    ----------
        cell_zone_list : typing.List[str]
            'cell_zone_list' child.
    
    """

    fluent_name = "activate-cell-zone"

    argument_names = \
        ['cell_zone_list']

    _child_classes = dict(
        cell_zone_list=cell_zone_list_cls,
    )

    return_type = "<object object at 0x7fabc4c48bf0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .skewness_correction_itr_count import skewness_correction_itr_count as skewness_correction_itr_count_cls
from .neighbor_correction_itr_count import neighbor_correction_itr_count as neighbor_correction_itr_count_cls
from .skewness_neighbor_coupling_1 import skewness_neighbor_coupling as skewness_neighbor_coupling_cls
from .vof_correction_itr_count import vof_correction_itr_count as vof_correction_itr_count_cls
from .flow_courant_number import flow_courant_number as flow_courant_number_cls
from .volume_fraction_courant_number import volume_fraction_courant_number as volume_fraction_courant_number_cls
from .explicit_momentum_under_relaxation import explicit_momentum_under_relaxation as explicit_momentum_under_relaxation_cls
from .explicit_pressure_under_relaxation import explicit_pressure_under_relaxation as explicit_pressure_under_relaxation_cls
from .explicit_volume_fraction_under_relaxation import explicit_volume_fraction_under_relaxation as explicit_volume_fraction_under_relaxation_cls

class p_v_controls(Group):
    fluent_name = ...
    child_names = ...
    skewness_correction_itr_count: skewness_correction_itr_count_cls = ...
    neighbor_correction_itr_count: neighbor_correction_itr_count_cls = ...
    skewness_neighbor_coupling: skewness_neighbor_coupling_cls = ...
    vof_correction_itr_count: vof_correction_itr_count_cls = ...
    flow_courant_number: flow_courant_number_cls = ...
    volume_fraction_courant_number: volume_fraction_courant_number_cls = ...
    explicit_momentum_under_relaxation: explicit_momentum_under_relaxation_cls = ...
    explicit_pressure_under_relaxation: explicit_pressure_under_relaxation_cls = ...
    explicit_volume_fraction_under_relaxation: explicit_volume_fraction_under_relaxation_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .max_vol_mag import max_vol_mag as max_vol_mag_cls
from .vol_frac_cutoff import vol_frac_cutoff as vol_frac_cutoff_cls

class set_velocity_and_vof_cutoffs_child(Group):
    """
    'child_object_type' of set_velocity_and_vof_cutoffs.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['max_vol_mag', 'vol_frac_cutoff']

    _child_classes = dict(
        max_vol_mag=max_vol_mag_cls,
        vol_frac_cutoff=vol_frac_cutoff_cls,
    )

    return_type = "<object object at 0x7f7d0bf948e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .command_list import command_list as command_list_cls
from .filename import filename as filename_cls

class export_modifications(Command):
    """
    Export all case modifications to a tsv file.
    
    Parameters
    ----------
        command_list : typing.List[str]
            'command_list' child.
        filename : str
            'filename' child.
    
    """

    fluent_name = "export-modifications"

    argument_names = \
        ['command_list', 'filename']

    _child_classes = dict(
        command_list=command_list_cls,
        filename=filename_cls,
    )

    return_type = "<object object at 0x7f7d0be4a230>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .background import background as background_cls
from .color_by_type import color_by_type as color_by_type_cls
from .foreground import foreground as foreground_cls
from .by_type import by_type as by_type_cls
from .by_surface import by_surface as by_surface_cls
from .far_field_faces import far_field_faces as far_field_faces_cls
from .inlet_faces import inlet_faces as inlet_faces_cls
from .interior_faces import interior_faces as interior_faces_cls
from .internal_faces import internal_faces as internal_faces_cls
from .outlet_faces import outlet_faces as outlet_faces_cls
from .overset_faces import overset_faces as overset_faces_cls
from .periodic_faces import periodic_faces as periodic_faces_cls
from .rans_les_interface_faces import rans_les_interface_faces as rans_les_interface_faces_cls
from .symmetry_faces import symmetry_faces as symmetry_faces_cls
from .axis_faces import axis_faces as axis_faces_cls
from .free_surface_faces import free_surface_faces as free_surface_faces_cls
from .traction_faces import traction_faces as traction_faces_cls
from .wall_faces import wall_faces as wall_faces_cls
from .interface_faces import interface_faces as interface_faces_cls
from .surface_2 import surface as surface_cls
from .skip_label import skip_label as skip_label_cls
from .automatic_skip import automatic_skip as automatic_skip_cls
from .reset_colors import reset_colors as reset_colors_cls
from .list_colors import list_colors as list_colors_cls

class colors(Group):
    fluent_name = ...
    child_names = ...
    background: background_cls = ...
    color_by_type: color_by_type_cls = ...
    foreground: foreground_cls = ...
    by_type: by_type_cls = ...
    by_surface: by_surface_cls = ...
    far_field_faces: far_field_faces_cls = ...
    inlet_faces: inlet_faces_cls = ...
    interior_faces: interior_faces_cls = ...
    internal_faces: internal_faces_cls = ...
    outlet_faces: outlet_faces_cls = ...
    overset_faces: overset_faces_cls = ...
    periodic_faces: periodic_faces_cls = ...
    rans_les_interface_faces: rans_les_interface_faces_cls = ...
    symmetry_faces: symmetry_faces_cls = ...
    axis_faces: axis_faces_cls = ...
    free_surface_faces: free_surface_faces_cls = ...
    traction_faces: traction_faces_cls = ...
    wall_faces: wall_faces_cls = ...
    interface_faces: interface_faces_cls = ...
    surface: surface_cls = ...
    skip_label: skip_label_cls = ...
    automatic_skip: automatic_skip_cls = ...
    command_names = ...

    def reset_colors(self, ):
        """
        Reset individual mesh surface colors to the defaults.
        """

    def list_colors(self, ):
        """
        List available colors.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .set_custom_frames import set_custom_frames as set_custom_frames_cls
from .video_1 import video as video_cls
from .read_animation import read_animation as read_animation_cls
from .write_animation import write_animation as write_animation_cls
from .stored_view import stored_view as stored_view_cls

class playback(Group):
    """
    'playback' child.
    """

    fluent_name = "playback"

    child_names = \
        ['set_custom_frames', 'video']

    command_names = \
        ['read_animation', 'write_animation', 'stored_view']

    _child_classes = dict(
        set_custom_frames=set_custom_frames_cls,
        video=video_cls,
        read_animation=read_animation_cls,
        write_animation=write_animation_cls,
        stored_view=stored_view_cls,
    )

    return_type = "<object object at 0x7f7d0bd2f190>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .use_inherent_material_color_1 import use_inherent_material_color as use_inherent_material_color_cls
from .reset_2 import reset as reset_cls
from .list_surfaces_by_color import list_surfaces_by_color as list_surfaces_by_color_cls
from .list_surfaces_by_material import list_surfaces_by_material as list_surfaces_by_material_cls
from .surfaces_8 import surfaces as surfaces_cls

class by_surface(Group):
    """
    'by_surface' child.
    """

    fluent_name = "by-surface"

    child_names = \
        ['use_inherent_material_color']

    command_names = \
        ['reset', 'list_surfaces_by_color', 'list_surfaces_by_material',
         'surfaces']

    _child_classes = dict(
        use_inherent_material_color=use_inherent_material_color_cls,
        reset=reset_cls,
        list_surfaces_by_color=list_surfaces_by_color_cls,
        list_surfaces_by_material=list_surfaces_by_material_cls,
        surfaces=surfaces_cls,
    )

    return_type = "<object object at 0x7fab93571190>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .set_cgns_export_filetype import set_cgns_export_filetype as set_cgns_export_filetype_cls

class settings(Group):
    fluent_name = ...
    command_names = ...

    def set_cgns_export_filetype(self, set_filetype: bool):
        """
        Select HDF5 or ADF as file format for CGNS.
        
        Parameters
        ----------
            set_filetype : bool
                'set_filetype' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .accelerated_non_iterative_time_marching import accelerated_non_iterative_time_marching as accelerated_non_iterative_time_marching_cls
from .convergence_acceleration_for_stretched_meshes import convergence_acceleration_for_stretched_meshes as convergence_acceleration_for_stretched_meshes_cls
from .discretization_scheme import discretization_scheme as discretization_scheme_cls
from .expert_2 import expert as expert_cls
from .flux_type_2 import flux_type as flux_type_cls
from .frozen_flux import frozen_flux as frozen_flux_cls
from .gradient_scheme import gradient_scheme as gradient_scheme_cls
from .high_order_term_relaxation import high_order_term_relaxation as high_order_term_relaxation_cls
from .multiphase_numerics import multiphase_numerics as multiphase_numerics_cls
from .nb_gradient_boundary_option import nb_gradient_boundary_option as nb_gradient_boundary_option_cls
from .nita_expert_controls import nita_expert_controls as nita_expert_controls_cls
from .nita import nita as nita_cls
from .overset_1 import overset as overset_cls
from .p_v_coupling_1 import p_v_coupling as p_v_coupling_cls
from .phase_based_vof_discretization import phase_based_vof_discretization as phase_based_vof_discretization_cls
from .reduced_rank_extrapolation import reduced_rank_extrapolation as reduced_rank_extrapolation_cls
from .reduced_rank_extrapolation_options import reduced_rank_extrapolation_options as reduced_rank_extrapolation_options_cls
from .residual_smoothing import residual_smoothing as residual_smoothing_cls
from .unsteady_1st_order import unsteady_1st_order as unsteady_1st_order_cls
from .unsteady_2nd_order import unsteady_2nd_order as unsteady_2nd_order_cls
from .unsteady_2nd_order_bounded import unsteady_2nd_order_bounded as unsteady_2nd_order_bounded_cls
from .unsteady_global_time import unsteady_global_time as unsteady_global_time_cls
from .vof_numerics import vof_numerics as vof_numerics_cls
from .warped_face_gradient_correction import warped_face_gradient_correction as warped_face_gradient_correction_cls
from .pseudo_time_method import pseudo_time_method as pseudo_time_method_cls
from .set_solution_methods_to_default import set_solution_methods_to_default as set_solution_methods_to_default_cls

class methods(Group):
    """
    'methods' child.
    """

    fluent_name = "methods"

    child_names = \
        ['accelerated_non_iterative_time_marching',
         'convergence_acceleration_for_stretched_meshes',
         'discretization_scheme', 'expert', 'flux_type', 'frozen_flux',
         'gradient_scheme', 'high_order_term_relaxation',
         'multiphase_numerics', 'nb_gradient_boundary_option',
         'nita_expert_controls', 'nita', 'overset', 'p_v_coupling',
         'phase_based_vof_discretization', 'reduced_rank_extrapolation',
         'reduced_rank_extrapolation_options', 'residual_smoothing',
         'unsteady_1st_order', 'unsteady_2nd_order',
         'unsteady_2nd_order_bounded', 'unsteady_global_time', 'vof_numerics',
         'warped_face_gradient_correction', 'pseudo_time_method']

    command_names = \
        ['set_solution_methods_to_default']

    _child_classes = dict(
        accelerated_non_iterative_time_marching=accelerated_non_iterative_time_marching_cls,
        convergence_acceleration_for_stretched_meshes=convergence_acceleration_for_stretched_meshes_cls,
        discretization_scheme=discretization_scheme_cls,
        expert=expert_cls,
        flux_type=flux_type_cls,
        frozen_flux=frozen_flux_cls,
        gradient_scheme=gradient_scheme_cls,
        high_order_term_relaxation=high_order_term_relaxation_cls,
        multiphase_numerics=multiphase_numerics_cls,
        nb_gradient_boundary_option=nb_gradient_boundary_option_cls,
        nita_expert_controls=nita_expert_controls_cls,
        nita=nita_cls,
        overset=overset_cls,
        p_v_coupling=p_v_coupling_cls,
        phase_based_vof_discretization=phase_based_vof_discretization_cls,
        reduced_rank_extrapolation=reduced_rank_extrapolation_cls,
        reduced_rank_extrapolation_options=reduced_rank_extrapolation_options_cls,
        residual_smoothing=residual_smoothing_cls,
        unsteady_1st_order=unsteady_1st_order_cls,
        unsteady_2nd_order=unsteady_2nd_order_cls,
        unsteady_2nd_order_bounded=unsteady_2nd_order_bounded_cls,
        unsteady_global_time=unsteady_global_time_cls,
        vof_numerics=vof_numerics_cls,
        warped_face_gradient_correction=warped_face_gradient_correction_cls,
        pseudo_time_method=pseudo_time_method_cls,
        set_solution_methods_to_default=set_solution_methods_to_default_cls,
    )

    return_type = "<object object at 0x7f79a695a230>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .methods_2 import methods as methods_cls
from .x import x as x_cls
from .y import y as y_cls
from .z import z as z_cls
from .point_vector import point_vector as point_vector_cls
from .point_normal import point_normal as point_normal_cls
from .compute_from_view_plane import compute_from_view_plane as compute_from_view_plane_cls
from .surface_aligned_normal import surface_aligned_normal as surface_aligned_normal_cls
from .p0_1 import p0 as p0_cls
from .p1 import p1 as p1_cls
from .p2 import p2 as p2_cls
from .bounded import bounded as bounded_cls
from .sample_point import sample_point as sample_point_cls
from .edges_2 import edges as edges_cls

class plane_surface_child(Group):
    """
    'child_object_type' of plane_surface.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['methods', 'x', 'y', 'z', 'point_vector', 'point_normal',
         'compute_from_view_plane', 'surface_aligned_normal', 'p0', 'p1',
         'p2', 'bounded', 'sample_point', 'edges']

    _child_classes = dict(
        methods=methods_cls,
        x=x_cls,
        y=y_cls,
        z=z_cls,
        point_vector=point_vector_cls,
        point_normal=point_normal_cls,
        compute_from_view_plane=compute_from_view_plane_cls,
        surface_aligned_normal=surface_aligned_normal_cls,
        p0=p0_cls,
        p1=p1_cls,
        p2=p2_cls,
        bounded=bounded_cls,
        sample_point=sample_point_cls,
        edges=edges_cls,
    )

    return_type = "<object object at 0x7fd5ebbfa2f0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .total_period_count import total_period_count as total_period_count_cls
from .time_step_count_2 import time_step_count as time_step_count_cls
from .total_time_step_count import total_time_step_count as total_time_step_count_cls
from .total_time import total_time as total_time_cls
from .incremental_time import incremental_time as incremental_time_cls
from .max_iter_per_step import max_iter_per_step as max_iter_per_step_cls
from .postprocess import postprocess as postprocess_cls
from .post_iter_per_time_step_count import post_iter_per_time_step_count as post_iter_per_time_step_count_cls

class dual_time_iterate(Command):
    fluent_name = ...
    argument_names = ...
    total_period_count: total_period_count_cls = ...
    time_step_count: time_step_count_cls = ...
    total_time_step_count: total_time_step_count_cls = ...
    total_time: total_time_cls = ...
    incremental_time: incremental_time_cls = ...
    max_iter_per_step: max_iter_per_step_cls = ...
    postprocess: postprocess_cls = ...
    post_iter_per_time_step_count: post_iter_per_time_step_count_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .force_child import force_child


class force(NamedObject[force_child], CreatableNamedObjectMixin[force_child]):
    """
    'force' child.
    """

    fluent_name = "force"

    child_object_type: force_child = force_child
    """
    child_object_type of force.
    """
    return_type = "<object object at 0x7f79a695a520>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_3 import option as option_cls
from .const_htc import const_htc as const_htc_cls
from .const_nu import const_nu as const_nu_cls

class heat_transfer(Group):
    """
    'heat_transfer' child.
    """

    fluent_name = "heat-transfer"

    child_names = \
        ['option', 'const_htc', 'const_nu']

    _child_classes = dict(
        option=option_cls,
        const_htc=const_htc_cls,
        const_nu=const_nu_cls,
    )

    return_type = "<object object at 0x7f7a03883a10>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .local_dt_child import local_dt_child


class local_dt(NamedObject[local_dt_child], _NonCreatableNamedObjectMixin[local_dt_child]):
    """
    'local_dt' child.
    """

    fluent_name = "local-dt"

    child_object_type: local_dt_child = local_dt_child
    """
    child_object_type of local_dt.
    """
    return_type = "<object object at 0x7f79a69cccd0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .method_4 import method as method_cls
from .type_1 import type as type_cls
from .frequency_1 import frequency as frequency_cls

class two_session_coupling(Group):
    """
    'two_session_coupling' child.
    """

    fluent_name = "two-session-coupling"

    child_names = \
        ['method', 'type', 'frequency']

    _child_classes = dict(
        method=method_cls,
        type=type_cls,
        frequency=frequency_cls,
    )

    return_type = "<object object at 0x7f79a670e670>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enable_roughness_correlation import enable_roughness_correlation as enable_roughness_correlation_cls
from .roughness_correlation_fcn import roughness_correlation_fcn as roughness_correlation_fcn_cls
from .geometric_roughness_ht_val import geometric_roughness_ht_val as geometric_roughness_ht_val_cls

class transition_sst_option(Group):
    fluent_name = ...
    child_names = ...
    enable_roughness_correlation: enable_roughness_correlation_cls = ...
    roughness_correlation_fcn: roughness_correlation_fcn_cls = ...
    geometric_roughness_ht_val: geometric_roughness_ht_val_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .refine_mesh import refine_mesh as refine_mesh_cls
from .boundary_zones import boundary_zones as boundary_zones_cls
from .layer_count import layer_count as layer_count_cls
from .parameters import parameters as parameters_cls

class multi_layer_refinement(Group):
    fluent_name = ...
    command_names = ...

    def refine_mesh(self, ):
        """
        Refine the mesh for multiple boundary layers.
        """

    def boundary_zones(self, ):
        """
        Specify boundary zones for refinement.
        """

    def layer_count(self, ):
        """
        Specify the layer count for refinement.
        """

    def parameters(self, ):
        """
        Specify parameters for multiple boundary layer refinement.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .body_force_function import body_force_function as body_force_function_cls
from .collision_function import collision_function as collision_function_cls
from .dpm_time_step_function import dpm_time_step_function as dpm_time_step_function_cls
from .erosion_accretion_function import erosion_accretion_function as erosion_accretion_function_cls
from .film_regime_function import film_regime_function as film_regime_function_cls
from .interpolation_function import interpolation_function as interpolation_function_cls
from .impingement_model_function import impingement_model_function as impingement_model_function_cls
from .output_function import output_function as output_function_cls
from .scalar_update_function import scalar_update_function as scalar_update_function_cls
from .source_function import source_function as source_function_cls
from .splashing_distribution_function import splashing_distribution_function as splashing_distribution_function_cls
from .number_of_scalars import number_of_scalars as number_of_scalars_cls
from .maximum_udf_species import maximum_udf_species as maximum_udf_species_cls

class user_defined_functions(Group):
    fluent_name = ...
    child_names = ...
    body_force_function: body_force_function_cls = ...
    collision_function: collision_function_cls = ...
    dpm_time_step_function: dpm_time_step_function_cls = ...
    erosion_accretion_function: erosion_accretion_function_cls = ...
    film_regime_function: film_regime_function_cls = ...
    interpolation_function: interpolation_function_cls = ...
    impingement_model_function: impingement_model_function_cls = ...
    output_function: output_function_cls = ...
    scalar_update_function: scalar_update_function_cls = ...
    source_function: source_function_cls = ...
    splashing_distribution_function: splashing_distribution_function_cls = ...
    number_of_scalars: number_of_scalars_cls = ...
    maximum_udf_species: maximum_udf_species_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .copy_from import copy_from as copy_from_cls
from .copy_to import copy_to as copy_to_cls

class copy(Command):
    """
    'copy' command.
    
    Parameters
    ----------
        copy_from : str
            'copy_from' child.
        copy_to : str
            'copy_to' child.
    
    """

    fluent_name = "copy"

    argument_names = \
        ['copy_from', 'copy_to']

    _child_classes = dict(
        copy_from=copy_from_cls,
        copy_to=copy_to_cls,
    )

    return_type = "<object object at 0x7f79a695ae30>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .pid import pid as pid_cls
from .temperature_spec import temperature_spec as temperature_spec_cls
from .temperature_rise import temperature_rise as temperature_rise_cls
from .heat_source import heat_source as heat_source_cls
from .tinf import tinf as tinf_cls
from .hc import hc as hc_cls
from .direction_spec import direction_spec as direction_spec_cls
from .coordinate_system import coordinate_system as coordinate_system_cls
from .flow_direction import flow_direction as flow_direction_cls
from .direction_vector import direction_vector as direction_vector_cls
from .ke_spec import ke_spec as ke_spec_cls
from .nut import nut as nut_cls
from .kl import kl as kl_cls
from .intermit import intermit as intermit_cls
from .k import k as k_cls
from .e import e as e_cls
from .o import o as o_cls
from .v2 import v2 as v2_cls
from .turb_intensity import turb_intensity as turb_intensity_cls
from .turb_length_scale import turb_length_scale as turb_length_scale_cls
from .turb_hydraulic_diam import turb_hydraulic_diam as turb_hydraulic_diam_cls
from .turb_viscosity_ratio import turb_viscosity_ratio as turb_viscosity_ratio_cls
from .turb_viscosity_ratio_profile import turb_viscosity_ratio_profile as turb_viscosity_ratio_profile_cls
from .rst_spec import rst_spec as rst_spec_cls
from .uu import uu as uu_cls
from .vv import vv as vv_cls
from .ww import ww as ww_cls
from .uv import uv as uv_cls
from .vw import vw as vw_cls
from .uw import uw as uw_cls
from .ksgs_spec import ksgs_spec as ksgs_spec_cls
from .ksgs import ksgs as ksgs_cls
from .sgs_turb_intensity import sgs_turb_intensity as sgs_turb_intensity_cls
from .mass_flow_multiplier import mass_flow_multiplier as mass_flow_multiplier_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .solar_shining_factor import solar_shining_factor as solar_shining_factor_cls

class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'pid',
         'temperature_spec', 'temperature_rise', 'heat_source', 'tinf', 'hc',
         'direction_spec', 'coordinate_system', 'flow_direction',
         'direction_vector', 'ke_spec', 'nut', 'kl', 'intermit', 'k', 'e',
         'o', 'v2', 'turb_intensity', 'turb_length_scale',
         'turb_hydraulic_diam', 'turb_viscosity_ratio',
         'turb_viscosity_ratio_profile', 'rst_spec', 'uu', 'vv', 'ww', 'uv',
         'vw', 'uw', 'ksgs_spec', 'ksgs', 'sgs_turb_intensity',
         'mass_flow_multiplier', 'solar_fluxes', 'solar_shining_factor']

    _child_classes = dict(
        geom_disable=geom_disable_cls,
        geom_dir_spec=geom_dir_spec_cls,
        geom_dir_x=geom_dir_x_cls,
        geom_dir_y=geom_dir_y_cls,
        geom_dir_z=geom_dir_z_cls,
        geom_levels=geom_levels_cls,
        geom_bgthread=geom_bgthread_cls,
        pid=pid_cls,
        temperature_spec=temperature_spec_cls,
        temperature_rise=temperature_rise_cls,
        heat_source=heat_source_cls,
        tinf=tinf_cls,
        hc=hc_cls,
        direction_spec=direction_spec_cls,
        coordinate_system=coordinate_system_cls,
        flow_direction=flow_direction_cls,
        direction_vector=direction_vector_cls,
        ke_spec=ke_spec_cls,
        nut=nut_cls,
        kl=kl_cls,
        intermit=intermit_cls,
        k=k_cls,
        e=e_cls,
        o=o_cls,
        v2=v2_cls,
        turb_intensity=turb_intensity_cls,
        turb_length_scale=turb_length_scale_cls,
        turb_hydraulic_diam=turb_hydraulic_diam_cls,
        turb_viscosity_ratio=turb_viscosity_ratio_cls,
        turb_viscosity_ratio_profile=turb_viscosity_ratio_profile_cls,
        rst_spec=rst_spec_cls,
        uu=uu_cls,
        vv=vv_cls,
        ww=ww_cls,
        uv=uv_cls,
        vw=vw_cls,
        uw=uw_cls,
        ksgs_spec=ksgs_spec_cls,
        ksgs=ksgs_cls,
        sgs_turb_intensity=sgs_turb_intensity_cls,
        mass_flow_multiplier=mass_flow_multiplier_cls,
        solar_fluxes=solar_fluxes_cls,
        solar_shining_factor=solar_shining_factor_cls,
    )

    return_type = "<object object at 0x7f79a6da51c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name_1 import name as name_cls
from .plot_window import plot_window as plot_window_cls
from .old_props import old_props as old_props_cls
from .frequency import frequency as frequency_cls
from .flow_frequency import flow_frequency as flow_frequency_cls
from .frequency_of import frequency_of as frequency_of_cls
from .report_defs import report_defs as report_defs_cls
from .print_2 import print as print_cls
from .title import title as title_cls
from .x_label import x_label as x_label_cls
from .y_label import y_label as y_label_cls
from .active import active as active_cls
from .evaluate import evaluate as evaluate_cls
from .plot_instantaneous_values import plot_instantaneous_values as plot_instantaneous_values_cls

class report_plots_child(Group):
    """
    'child_object_type' of report_plots.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'plot_window', 'old_props', 'frequency', 'flow_frequency',
         'frequency_of', 'report_defs', 'print', 'title', 'x_label',
         'y_label', 'active', 'evaluate', 'plot_instantaneous_values']

    _child_classes = dict(
        name=name_cls,
        plot_window=plot_window_cls,
        old_props=old_props_cls,
        frequency=frequency_cls,
        flow_frequency=flow_frequency_cls,
        frequency_of=frequency_of_cls,
        report_defs=report_defs_cls,
        print=print_cls,
        title=title_cls,
        x_label=x_label_cls,
        y_label=y_label_cls,
        active=active_cls,
        evaluate=evaluate_cls,
        plot_instantaneous_values=plot_instantaneous_values_cls,
    )

    return_type = "<object object at 0x7f7d0bed6a10>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .porous_jump_child import porous_jump_child


class porous_jump(NamedObject[porous_jump_child], _NonCreatableNamedObjectMixin[porous_jump_child]):
    """
    'porous_jump' child.
    """

    fluent_name = "porous-jump"

    child_object_type: porous_jump_child = porous_jump_child
    """
    child_object_type of porous_jump.
    """
    return_type = "<object object at 0x7f79e82d8820>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .reference_pressure import reference_pressure as reference_pressure_cls
from .reference_density import reference_density as reference_density_cls
from .reference_bulk_modulus import reference_bulk_modulus as reference_bulk_modulus_cls
from .density_exponent import density_exponent as density_exponent_cls
from .maximum_density_ratio import maximum_density_ratio as maximum_density_ratio_cls
from .minimum_density_ratio import minimum_density_ratio as minimum_density_ratio_cls

class compressible_liquid(Group):
    """
    'compressible_liquid' child.
    """

    fluent_name = "compressible-liquid"

    child_names = \
        ['reference_pressure', 'reference_density', 'reference_bulk_modulus',
         'density_exponent', 'maximum_density_ratio',
         'minimum_density_ratio']

    _child_classes = dict(
        reference_pressure=reference_pressure_cls,
        reference_density=reference_density_cls,
        reference_bulk_modulus=reference_bulk_modulus_cls,
        density_exponent=density_exponent_cls,
        maximum_density_ratio=maximum_density_ratio_cls,
        minimum_density_ratio=minimum_density_ratio_cls,
    )

    return_type = "<object object at 0x7f7d7fef31f0>"
